package com.zehong.web.controller.lpgRegulation;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TLpgSafeCheckRecord;
import com.zehong.system.service.ITLpgSafeCheckRecordService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 液化石油安检记录Controller
 * 
 * @author zehong
 * @date 2024-07-22
 */
@RestController
@RequestMapping("/lpg/check")
public class TLpgSafeCheckRecordController extends BaseController
{
    @Autowired
    private ITLpgSafeCheckRecordService tLpgSafeCheckRecordService;

    /**
     * 查询液化石油安检记录列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TLpgSafeCheckRecord tLpgSafeCheckRecord)
    {
        startPage();
        List<TLpgSafeCheckRecord> list = tLpgSafeCheckRecordService.selectTLpgSafeCheckRecordList(tLpgSafeCheckRecord);
        return getDataTable(list);
    }

    /**
     * 导出液化石油安检记录列表
     */
    @Log(title = "液化石油安检记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TLpgSafeCheckRecord tLpgSafeCheckRecord)
    {
        List<TLpgSafeCheckRecord> list = tLpgSafeCheckRecordService.selectTLpgSafeCheckRecordList(tLpgSafeCheckRecord);
        ExcelUtil<TLpgSafeCheckRecord> util = new ExcelUtil<TLpgSafeCheckRecord>(TLpgSafeCheckRecord.class);
        return util.exportExcel(list, "液化石油安检记录数据");
    }

    /**
     * 获取液化石油安检记录详细信息
     */
    @GetMapping(value = "/{safeCheckId}")
    public AjaxResult getInfo(@PathVariable("safeCheckId") Long safeCheckId)
    {
        return AjaxResult.success(tLpgSafeCheckRecordService.selectTLpgSafeCheckRecordById(safeCheckId));
    }

    /**
     * 新增液化石油安检记录
     */
    @Log(title = "液化石油安检记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TLpgSafeCheckRecord tLpgSafeCheckRecord)
    {
        return toAjax(tLpgSafeCheckRecordService.insertTLpgSafeCheckRecord(tLpgSafeCheckRecord));
    }

    /**
     * 修改液化石油安检记录
     */
    @Log(title = "液化石油安检记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TLpgSafeCheckRecord tLpgSafeCheckRecord)
    {
        return toAjax(tLpgSafeCheckRecordService.updateTLpgSafeCheckRecord(tLpgSafeCheckRecord));
    }

    /**
     * 删除液化石油安检记录
     */
    @Log(title = "液化石油安检记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{safeCheckIds}")
    public AjaxResult remove(@PathVariable Long[] safeCheckIds)
    {
        return toAjax(tLpgSafeCheckRecordService.deleteTLpgSafeCheckRecordByIds(safeCheckIds));
    }
}
